
------------------------------------------------------------------------------------
-- Name : nUI_Plugin_TempMovers                                          
-- Copyright : Tina Kirby AKA Xrystal (C) 2009/2010 All Rights Reserved      
-- Contact : xrystal@swangen.co.uk                                           
-- Download Sites :                                                          
-- Version : 1.01.00 - New
-- Version : 1.02.00 - Added fake player frame functionality on target change
-- Version : 1.03.00 - also used fake player frame stuff on entering world
-- Version : 1.04.00 - Use Paladin and Warlock OnLoad and Update routines when initialising 
-- Version : 1.05.00 - Use Druid UpdateShown routine when initialising
-- Version : 1.06.00 - Hide Druid Eclipse Bar so as not to call OnShow too soon
-- Version : 1.07.00 - Make sure Druid Eclipse Bar is allowed to be moved
------------------------------------------------------------------------------------

--[[ Use Addon Wide Data Table ]]--
local addonName,addonData = ...

local PTM_Frame = CreateFrame("Frame","nUI_PowerBarFrame",UIParent);
PTM_Frame.unit = "player";
PTM_Frame:SetParent(UIParent);
PTM_Frame:SetPoint( "TOP", nUI_TopBars, "BOTTOM", 0, 12 );


-----------------------------------------------------------------------------------------------
-- DEATH KNIGHT
-- Rune Frame
-----------------------------------------------------------------------------------------------
local function PTM_DeathKnightRuneInit()
    PlayerFrameBottomManagedFramesContainer:SetParent(PTM_Frame)

    RuneFrame:SetParent(PlayerFrameBottomManagedFramesContainer)
    nUI_Movers:lockFrame(RuneFrame,true,"nUI_RuneFrame")
end

-----------------------------------------------------------------------------------------------
-- DEMON HUNTER
-- No special frames to monitor
-----------------------------------------------------------------------------------------------


-----------------------------------------------------------------------------------------------
-- DRUID
-- Moonkin Alternate Mana Bar
-- Cat Combo Point Bar
-----------------------------------------------------------------------------------------------
local function PTM_DruidPBInit()
    PlayerFrameBottomManagedFramesContainer:SetParent(PTM_Frame)

    AlternatePowerBar:SetParent(PlayerFrameBottomManagedFramesContainer)        
    nUI_Movers:lockFrame( AlternatePowerBar, true, "nUI_DruidAlternatePowerBar" ); 

    DruidComboPointBarFrame:SetParent(PlayerFrameBottomManagedFramesContainer)    
    nUI_Movers:lockFrame( DruidComboPointBarFrame, true, "nUI_DruidComboPointFrame" ); 		
end


-----------------------------------------------------------------------------------------------
-- EVOKER
-- Essence Bar 
-- Augmentation : Ebon Might Bar
-----------------------------------------------------------------------------------------------
local function PTM_EvokerEssenceInit()
    PlayerFrameBottomManagedFramesContainer:SetParent(PTM_Frame)

    EvokerEbonMightBar:SetParent(PlayerFrameBottomManagedFramesContainer)
    nUI_Movers:lockFrame(EvokerEbonMightBar,true,"nUI_EvokerEbonMightBar")

    EssencePlayerFrame:SetParent(PlayerFrameBottomManagedFramesContainer)
    nUI_Movers:lockFrame(EssencePlayerFrame,true,"nUI_EssencePlayerFrame")
end

-----------------------------------------------------------------------------------------------
-- HUNTER
-- No special power bars
-----------------------------------------------------------------------------------------------

-----------------------------------------------------------------------------------------------
-- MAGE
-- Arcane Charges Bar
-----------------------------------------------------------------------------------------------
local function PTM_MagePBInit()
    PlayerFrameBottomManagedFramesContainer:SetParent(PTM_Frame)

    MageArcaneChargesFrame:SetParent(PlayerFrameBottomManagedFramesContainer)        
    nUI_Movers:lockFrame( MageArcaneChargesFrame, true, "nUI_MageArcaneChargesFrame" ); 		
end

-----------------------------------------------------------------------------------------------
-- MONK
-- Brewmaster : Stagger 
-- Harmony Bar
-----------------------------------------------------------------------------------------------
local function PTM_MonkPBInit()
    PlayerFrameBottomManagedFramesContainer:SetParent(PTM_Frame)

    MonkStaggerBar:SetParent(PlayerFrameBottomManagedFramesContainer);
    nUI_Movers:lockFrame( MonkStaggerBar, false, "nUI_MonkStaggerBar" );

    MonkHarmonyBarFrame:SetParent(PlayerFrameBottomManagedFramesContainer);
    nUI_Movers:lockFrame( MonkHarmonyBarFrame, false, "nUI_MonkHarmonyBarFrame" );
end

-----------------------------------------------------------------------------------------------
-- PALADIN
-- Holy Power Bar
-----------------------------------------------------------------------------------------------
local function PTM_PaladinPBInit()
    PlayerFrameBottomManagedFramesContainer:SetParent(PTM_Frame)

    PaladinPowerBarFrame:SetParent(PlayerFrameBottomManagedFramesContainer)        
    nUI_Movers:lockFrame( PaladinPowerBarFrame, false, "nUI_PaladinPowerBarFrame" );
end

-----------------------------------------------------------------------------------------------
-- PRIEST
-- Shadow : Alternate Mana Bar
-----------------------------------------------------------------------------------------------
local function PTM_PriestPBInit()
    PlayerFrameBottomManagedFramesContainer:SetParent(PTM_Frame)

    AlternatePowerBar:SetParent(PlayerFrameBottomManagedFramesContainer)        
    nUI_Movers:lockFrame( AlternatePowerBar, true, "nUI_PriestAlternatePowerBar" ); 	
end

-----------------------------------------------------------------------------------------------
-- ROGUE
-- Combo Points Bar
-----------------------------------------------------------------------------------------------
local function PTM_RogueComboInit()
    PlayerFrameBottomManagedFramesContainer:SetParent(PTM_Frame)

    RogueComboPointBarFrame:SetParent(PlayerFrameBottomManagedFramesContainer)
    nUI_Movers:lockFrame( RogueComboPointBarFrame, true, "nUI_RogueComboPointFrame" ); 		
end

-----------------------------------------------------------------------------------------------
-- SHAMAN
-- Totem Bar
-- Alternate Mana Bar
-----------------------------------------------------------------------------------------------
local function PTM_ShamanTotemsInit()
    PlayerFrameBottomManagedFramesContainer:SetParent(PTM_Frame)

    TotemFrame:SetParent(PlayerFrameBottomManagedFramesContainer)        
    nUI_Movers:lockFrame( TotemFrame, true, "nUI_ShamanTotemFrame" ); 		

    AlternatePowerBar:SetParent(PlayerFrameBottomManagedFramesContainer)        
    nUI_Movers:lockFrame( AlternatePowerBar, true, "nUI_ShamanAlternatePowerBar" ); 		
end

-----------------------------------------------------------------------------------------------
-- WARLOCK 
-- Shard Bar
-----------------------------------------------------------------------------------------------
local function PTM_WarlockPBInit()
    PlayerFrameBottomManagedFramesContainer:SetParent(PTM_Frame)

    WarlockPowerFrame:SetParent(PlayerFrameBottomManagedFramesContainer)        
    nUI_Movers:lockFrame( WarlockPowerFrame, false, "nUI_WarlockPowerFrame" );
end

-----------------------------------------------------------------------------------------------
-- WARRIOR
-- No special power bars
-----------------------------------------------------------------------------------------------


local function PTM_Events(self,event,...)

	local arg1,arg2,arg3,arg4,arg5,arg6 = ...;
    local refreshFrame = false    
	
	if ( event == "ADDON_LOADED" and arg1 == addonName ) then	
		self.unit = PlayerFrame.unit;		
		
	elseif ( event == "PLAYER_ENTERING_WORLD") then
        refreshFrame = true
		self:UnregisterEvent(event);
        
    elseif ( event == "PLAYER_SPECIALIZATION_CHANGED") or
    ( event == "ACTIVE_TALENT_GROUP_CHANGED") or
    ( event == "ACTIVE_PLAYER_SPECIALIZATION_CHANGED") then
        refreshFrame = true  
        
    elseif ( event == "PLAYER_REGEN_ENABLED") then
        if self.awaitingRefresh then
            refreshFrame = true
        end
    
	end
    
    if not refreshFrame then return end

	local emptyVar, class = UnitClass("player");
    
    if InCombatLockdown() then
        self:RegisterEvent("PLAYER_REGEN_ENABLED")
        self.awaitingRefresh = true
        return        
    end
    
    if class == "MONK" then PTM_MonkPBInit()
    elseif class == "PALADIN" then PTM_PaladinPBInit(); 
    elseif class == "WARLOCK" then PTM_WarlockPBInit(); 
    elseif class == "MAGE" then PTM_MagePBInit(); 
    elseif class == "SHAMAN" then PTM_ShamanTotemsInit();
    elseif class == "DRUID" then PTM_DruidPBInit();
    elseif class == "PRIEST" then PTM_PriestPBInit();
    elseif class == "ROGUE" then PTM_RogueComboInit();
    elseif class =="EVOKER" then PTM_EvokerEssenceInit();
    elseif class =="DEATHKNIGHT" then PTM_DeathKnightRuneInit();
    end

end

--[[ Register the events we want to watch ]]--
PTM_Frame:SetScript( "OnEvent", PTM_Events );
PTM_Frame:RegisterEvent( "ADDON_LOADED" );
PTM_Frame:RegisterEvent( "PLAYER_ENTERING_WORLD" );
PTM_Frame:RegisterEvent( "PLAYER_SPECIALIZATION_CHANGED")
PTM_Frame:RegisterEvent( "ACTIVE_TALENT_GROUP_CHANGED")
PTM_Frame:RegisterEvent( "ACTIVE_PLAYER_SPECIALIZATION_CHANGED")

PTM_Frame:Show()

